@@ -1,17 +1,15 @@
 package Digest::Whirlpool;
 use strict;
-use warnings;
 use base 'Digest::base';
 
 use XSLoader ();
-BEGIN {
-    our $VERSION = '1.0.10';
 
-    XSLoader::load __PACKAGE__, $VERSION;
+our $VERSION = '1.09';
 
-    # Pre-1.0.4 used base64digest, maintain API compatibility with it.
-    *base64digest = \&Digest::base::b64digest;
-}
+XSLoader::load __PACKAGE__, $VERSION;
+
+# Pre-1.0.4 used base64digest, maintain API compatibility with it.
+*base64digest = \&Digest::base::b64digest;
 
 1;
 
